=== modified file 'docs/create_table.rst'
--- docs/create_table.rst	2011-01-07 03:04:54 +0000
+++ docs/create_table.rst	2011-01-09 21:30:25 +0000
@@ -20,40 +20,40 @@
     LIKE different_table_name
     [engine_options]
 
-create_definition:
+create_definition: ::
 
     column_name column_definition
-  | [CONSTRAINT [symbol] ] PRIMARY KEY [index_type]
-    (index_column_name, ...)
-  | INDEX [index_name] (index_column_name, ...)
-    (index_column_name, ...)
-  | [CONSTRAINT [symbol] ] UNIQUE [INDEX]
-    (index_column_name, ...)
-  | [CONSTRAINT [symbol] ] FOREIGN KEY [index_name] (index_column_name, ...)
+    [CONSTRAINT [symbol] ] PRIMARY KEY [index_type]
+    (index_column_name, ...)
+    INDEX [index_name] (index_column_name, ...)
+    (index_column_name, ...)
+    [CONSTRAINT [symbol] ] UNIQUE [INDEX]
+    (index_column_name, ...)
+    [CONSTRAINT [symbol] ] FOREIGN KEY [index_name] (index_column_name, ...)
     reference_definition
-  | CHECK (expr)
-
-column_definition:
-
-  data_type [NOT NULL | NULL] [DEFAULT default_value]
+    CHECK (expr)
+
+column_definition: ::
+
+	data_type [NOT NULL | NULL] [DEFAULT default_value]
     [AUTO_INCREMENT] [UNIQUE [KEY] | [PRIMARY] KEY]
     [COMMENT 'string']
     [reference_definition]
 
-data_type:
+data_type: ::
 
-  | INTEGER
-  | BIGINT
-  | DOUBLE[(length, decimals)]
-  | DECIMAL[(length[,decimals])]
-  | DATE
-  | TIMESTAMP
-  | DATETIME
-  | VARCHAR(length) [COLLATE collation_name]
-  | VARBINARY(length)
-  | BLOB
-  | TEXT [BINARY] [COLLATE collation_name]
-  | ENUM(value1, value2, value3, ...) [COLLATE collation_name]
+	* INTEGER
+	* BIGINT
+	* DOUBLE[(length, decimals)]
+	* DECIMAL[(length[,decimals])]
+	* DATE
+	* TIMESTAMP
+	* DATETIME
+	* VARCHAR(length) [COLLATE collation_name]
+	* VARBINARY(length)
+	* BLOB
+	* TEXT [BINARY] [COLLATE collation_name]
+	* ENUM(value1, value2, value3, ...) [COLLATE collation_name]
 
 reference_option:
   RESTRICT | CASCADE | SET NULL | NO ACTION

=== added file 'docs/data_types.rst'
--- docs/data_types.rst	1970-01-01 00:00:00 +0000
+++ docs/data_types.rst	2011-01-11 02:37:50 +0000
@@ -0,0 +1,12 @@
+Data Types
+==========
+
+Drizzle data types can be grouped into the following categories:
+
+.. toctree:: 
+   :maxdepth: 2
+
+   numeric_data_types
+   date_time_data_types
+   string_data_types
+   uuid_data_type
\ No newline at end of file

=== added file 'docs/date_time_data_types.rst'
--- docs/date_time_data_types.rst	1970-01-01 00:00:00 +0000
+++ docs/date_time_data_types.rst	2011-01-13 02:58:57 +0000
@@ -0,0 +1,52 @@
+Date and Time Data Types
+========================
+
+Of the SQL date and time types, Drizzle supports:
+
+**Date/Time Types**
+
++------------+---------------------------+-----------------------+------------------------+---------------+---------------+
+|Data Type   |Lowest Value (or NULL)     |Maximum Value          |Description	          |Storage Size   |Resolution     |
++============+===========================+=======================+========================+===============+===============+
+|TIMESTAMP   |'0001-01-01 00:00:00'      |'9999-12-31 23:59:59'  |both date and time      |8 bytes        |1 microsecond  |
++------------+---------------------------+-----------------------+------------------------+---------------+---------------+
+|DATE        |'0001-01-01'               |'9999-12-31'           |dates only              |4 bytes        |1 day          +
++------------+---------------------------+-----------------------+------------------------+---------------+---------------+
+|TIME        |'00:00:00'                 |'23:59:59'             |time of day             |8 bytes        |1 microsecond  +
++------------+---------------------------+-----------------------+------------------------+---------------+---------------+
+|DATETIME    |'0001-01-01 00:00:00'      |'9999-12-31 23:59:59'  |both date and time      |8 bytes        |1 microsecond  |
++------------+---------------------------+-----------------------+------------------------+---------------+---------------+
+
+TIMESTAMP
+---------
+
+To create a TIMESTAMP column that uses microseconds you simply need to specify TIMESTAMP(6) in your table definition, for example: ::
+
+	CREATE TABLE `t1` (
+	`a` INT DEFAULT NULL,
+	`b` TIMESTAMP(6) NULL DEFAULT NULL
+	) ENGINE=InnoDB
+
+You can then use the following (but note that ON DEFAULT/UPDATE CURRENT_TIMESTAMP works with microseconds as well): ::
+
+	insert into t1 values (1, '2010-01-10 07:32:43.234567');
+
+The new table now looks like this:
+
++------+----------------------------+
+|a     |b                           |
++------+----------------------------+
+|1     |2010-01-10 07:32:43.234567  |
++------+----------------------------+
+
+DATE
+----
+
+In Drizzle, valid date inputs begin at 0001-01-01 rather than 0000-00-00, which is not a valid date. NULL is also a valid DATE entry.
+
+TIME
+----
+
+Drizzle's TIME data type has a range of 00:00:00 - 24:59:59, while MySQL's TIME data type has a range of -838:59:59 - 838:59:59.
+
+To prevent data loss to this type when converting from MySQL -> Drizzle, the conversion changes TIME to an INT of the number of seconds. For example, 00:00:00 becomes 0, 01:00:00 becomes 3600, and -01:00:00 becomes -3600.

=== modified file 'docs/include.am'
--- docs/include.am	2010-11-01 23:18:55 +0000
+++ docs/include.am	2011-01-12 19:17:18 +0000
@@ -16,7 +16,7 @@
 # Makefile for Sphinx documentation
 #
 
-SPHINXOPTS    = -D release=${PANDORA_RELEASE_VERSION}
+SPHINXOPTS    = -W -D release=${PANDORA_RELEASE_VERSION}
 PAPER         =
 SPHINX_BUILDDIR      = ${top_builddir}/docs
 

=== modified file 'docs/index.rst'
--- docs/index.rst	2011-01-07 03:49:07 +0000
+++ docs/index.rst	2011-01-14 04:34:23 +0000
@@ -24,7 +24,6 @@
 
 Introduction:
 -------------
-   
 .. toctree::
    :maxdepth: 2
    
@@ -36,7 +35,6 @@
 
 SQL Language:
 -------------
-
 .. toctree::
    :maxdepth: 2
 
@@ -51,11 +49,17 @@
    dynamic 
    getting_information 
    transactional 
-   administrative 
-
-Advanced Topics:
-----------------
-
+   administrative
+
+Data Types:
+-----------
+.. toctree::
+   :maxdepth: 2
+
+   data_types
+
+User Level Topics:
+------------------
 .. toctree::
    :maxdepth: 2
 
@@ -64,7 +68,7 @@
    logging
 
 Configuration:
-^^^^^^^^^^^^^^
+--------------
 .. toctree::
    :maxdepth: 2
 
@@ -76,8 +80,10 @@
 .. toctree::
    :maxdepth: 2
 
+   plugins/list
+
 Architecture:
-^^^^^^^^^^^^^
+-------------
 .. toctree::
    :maxdepth: 2
 
@@ -85,7 +91,7 @@
    replication
 
 Clients:
-^^^^^^^^
+--------
 .. toctree::
    :maxdepth: 2
 
@@ -94,7 +100,7 @@
    clients/drizzleadmin.rst
 
 libdrizzle:
-^^^^^^^^^^^
+-----------
 .. toctree::
    :maxdepth: 2
 
@@ -102,7 +108,7 @@
    libdrizzle/developer.rst
 
 Testing:
-
+--------
 .. toctree::
    :maxdepth: 2
  

=== added file 'docs/numeric_data_types.rst'
--- docs/numeric_data_types.rst	1970-01-01 00:00:00 +0000
+++ docs/numeric_data_types.rst	2011-01-13 03:34:11 +0000
@@ -0,0 +1,18 @@
+Numeric Data Types
+==================
+
+Drizzle does not support TINYINT, SMALLINT or MEDIUMINT. Integer operations have been optimized around 32- and 64-bit integers.
+
+BIGINT and INTEGER exist as Drizzle's two integer numerical types. BIGINT is a 64-bit integer, while INTEGER is a 32-bit integer.
+
++---------+--------------+---------------------+--------------------------------------------+
+|Name     |Storage Size  |Description          |Range                                       |
++=========+==============+=====================+============================================+
+|integer  |4 bytes	 |most common integer  |-2147483648 to +2147483647                  |
++---------+--------------+---------------------+--------------------------------------------+
+|bigint	  |8 bytes	 |larger-range integer |-9223372036854775808 to 9223372036854775807 |
++---------+--------------+---------------------+--------------------------------------------+
+
+AUTO_INCREMENT is supported for INT and BIGINT.
+
+DOUBLE is the system's native double type. DOUBLE represents double-precision floating-point values that require eight bytes each for   storage.

=== added file 'docs/string_data_types.rst'
--- docs/string_data_types.rst	1970-01-01 00:00:00 +0000
+++ docs/string_data_types.rst	2011-01-14 04:01:44 +0000
@@ -0,0 +1,19 @@
+String Data Types
+=================
+
+The string types in Drizzle are explained in the following groupings:
+
+VARCHAR and VARBINARY
+---------------------
+
+A VARCHAR or VARBINARY type is used to store variable length data. Indexes on these types are by default the full length of the data stored. The only difference between the two types is the COLLATION which is used. VARBINARY uses a binary collation for all index usage.
+
+TEXT and BLOB
+-------------
+
+A TEXT or BLOB type is used to store data which is over XXX in size. Indexes on these types must specify the number of character or bytes which should be used. The only difference between the two types is the COLLATION which is used. A BLOB uses a binary collation for all index usage.
+
+ENUM
+----
+
+Enum (enumerated) types are static lists of strings that are defined on table creation. They can be used to represent a collection of string types that are sorted based on the order that they are created.
\ No newline at end of file

=== added file 'docs/uuid_data_type.rst'
--- docs/uuid_data_type.rst	1970-01-01 00:00:00 +0000
+++ docs/uuid_data_type.rst	2011-01-11 02:37:50 +0000
@@ -0,0 +1,14 @@
+UUID Data Type
+==============
+
+The data type uuid stores Universally Unique Identifiers (UUID). Some systems refer to this data type as "globally unique identifier", or GUID, instead. 
+
+This identifier is a 128-bit quantity that is generated by an algorithm designed to make it very unlikely that the same identifier will be generated by anyone else in the world using the same algorithm. The purpose of UUIDs is to enable distributed systems to uniquely identify information without significant central coordination. 
+
+sequence generators, which are only unique within a single database.
+
+A UUID consists of 32 hexadecimal digits, displayed in 5 groups separated by hyphens, in the form 8-4-4-4-12 for a total of 36 characters (32 digits and 4 hyphens). For example:
+
+550e8400-e29b-41d4-a716-446655440000
+
+UUIDs are documented as part of ISO/IEC 11578:1996 "Information technology – Open Systems Interconnection – Remote Procedure Call (RPC)" and more recently in ITU-T Rec. X.667 | ISO/IEC 9834-8:2005. The IETF published Standards Track RFC 4122 that is technically equivalent with ITU-T Rec. X.667 | ISO/IEC 9834-8.
\ No newline at end of file

=== removed directory 'plugin/drizzle_protocol/docs'
=== removed file 'plugin/drizzle_protocol/docs/index.rst'
--- plugin/drizzle_protocol/docs/index.rst	2010-12-20 21:56:40 +0000
+++ plugin/drizzle_protocol/docs/index.rst	1970-01-01 00:00:00 +0000
@@ -1,36 +0,0 @@
-Drizzle Protocol
-==============
-
-The Drizzle Protocol plugin allows Drizzle compatible clients to connect to Drizzle (currently this is identical to the MySQL Protocol).
-
-Configuration
--------------
-
-There are several server variables to control the Drizzle Protocol.
-
-**drizzle-protocol.port** arg (=4427)
-  The port number to use with Drizzle connections (0 is the same as 4427)
-
-**drizzle-protocol.connect-timeout** arg (=10)
-  Connection timeout in seconds
-
-**drizzle-protocol.read-timeout** arg (=30)
-  Port read timeout in seconds
-
-**drizzle-protocol.write-timeout** arg (=60)
-  Port write timeout in seconds
-
-**drizzle-protocol.retry-count** arg (=10)
-  Retry count for the read and write timeout before killing the connection
-
-**drizzle-protocol.buffer-length** arg (=16384)
-  Buffer length
-
-**drizzle-protocol.bind-address** arg
-  Address to bind to
-
-**drizzle-protocol.max-connections** arg (=1000)
-  Maximum simultaneous connections
-
-**drizzle-protocol.admin-ip-addresses** arg
-  A comma seprated list of IP addresses for admin tools to connect from

